from enum import Enum


class TaskActionTypeEnum(Enum):
    """description"""

    TASK_ACTION_EXEC = 0
    TASK_ACTION_COM_HANDLER = 5
    TASK_ACTION_SEND_MAIL = 6
    TASK_ACTION_SHOW_MESSAGE = 7
